#!/usr/bin/env python3
# --------------------------------------------------------------------------------------------------
# Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
# Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
# This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
# shipped with this file and also available at: https://github.com/seqan/raptor/blob/main/LICENSE.md
# --------------------------------------------------------------------------------------------------
#
# Usage parse.py <input_file>
#
# Extracts relative slowdown from benchmark results.
# E.g. ./test/benchmark/bin_influence_benchmark --benchmark_repetitions=5 --benchmark_report_aggregates_only=true
#                                               --benchmark_out=results_minimiser.json --benchmark_out_format=json
import argparse
import json
import pandas

def create_data_frame(json_string, aggregate_name):
    assert aggregate_name == 'mean' or aggregate_name == 'median'
    with pandas.option_context('mode.chained_assignment', None):
        data = pandas.read_json(json_string, convert_dates=False)
        data = data[data.aggregate_name == aggregate_name]
        data = data.loc[:, ['run_name','cpu_time']]
        data.reset_index(drop=True, inplace=True)
        min_time = data['cpu_time'][0]
        data['Factor'] = data.apply(lambda row: round(row['cpu_time'] / min_time, 2), axis='columns')
        data['run_name'] = data['run_name'].apply(lambda x: x.split('/')[1])
        data.rename(columns={'run_name' : 'Bins', 'cpu_time' : 'Time [ns]'}, inplace=True)
        return data

def process_json(path, aggregate_name):
    assert aggregate_name == 'mean' or aggregate_name == 'median'
    with open(path, 'r') as json_file:
        benchmark_json_string = json.dumps(json.load(json_file)['benchmarks'])
    return create_data_frame(benchmark_json_string, aggregate_name)

parser = argparse.ArgumentParser(description='Extracts relative slowdown from benchmark results. E.g., from the file '
                                             'generated by calling `./test/benchmark/bin_influence_benchmark --benchm'
                                             'ark_repetitions=5 --benchmark_report_aggregates_only=true --benchmark_o'
                                             'ut=results_minimiser.json --benchmark_out_format=json`',
                                 formatter_class=argparse.ArgumentDefaultsHelpFormatter)
parser.add_argument('input', type=str, help='JSON File from bin_influence_benchmark.')
arguments = parser.parse_args()

print(process_json(arguments.input, 'mean'))
print(process_json(arguments.input, 'median'))



#!/usr/bin/env python3

# --------------------------------------------------------------------------------------------------
# Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
# Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
# This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
# shipped with this file and also available at: https://github.com/seqan/raptor/blob/main/LICENSE.md
# --------------------------------------------------------------------------------------------------

import numpy as np
import pandas as pd

import os
import re
import time

BINS=65536
READ_COUNT=2**20
REPEATS=10
INPUT_BASE = '/example/runs'

def process_output(path):
    with open(path) as f:
        tp = 0
        fp = 0
        fn = 0
        bin_to_ub = {}
        for line in f:
            if line[0] == '#':
                try:
                    [ub, bin] = line.strip().split('\t')
                    ub = int(ub[1:])
                    bin = int(re.match('bin_(\d+)\..*$', os.path.basename(bin))[1])
                    bin_to_ub[bin] = ub
                except ValueError:
                    pass
                continue
            try:
                [x, y] = line.strip().split('\t')
            except ValueError:
                fn += 1
                continue
            [read_id, bins] = [int(x), [int(e) for e in y.split(',') if e != '']]
            true_id = bin_to_ub[(read_id % READ_COUNT) // (READ_COUNT // BINS)]
            if true_id in bins:
                tp += 1
                if len(bins) != 1:
                    fp += len(bins) - 1
            else:
                fn += 1
                fp += len(bins)
        return [int(tp/REPEATS),int(fp/REPEATS),int(fn/REPEATS)]

def process_time(path):
    time = []
    mem = []
    with open(path) as f:
        for i, line in enumerate(f):
            if i == 4:
                time = line.strip().split(' ')[-1].split(':')
                if len(time) == 3:
                    time = '{}:{:02d}'.format(int(time[0]) * 60 + int(time[1]), int(time[2]))
                elif len(time) == 2:
                    if int(time[0]) == 0:
                        time = '{}:{}'.format(time[0], time[1])
                    else:
                        time = '{}:{:02d}'.format(time[0], round(float(time[1])))
            if i == 9:
                mem = round(int(line.strip().split(' ')[-1]) / 1024)
    return [time, mem]

def process_internal_time(path):
    with open(path) as f:
        line = f.readline()
        line = f.readline()
        [ibf_time, read_time, compute_time] = line.strip().split('\t')
        return [ibf_time, read_time, compute_time]

def get_param_list(path):
    result = []
    for entry in os.listdir(path):
        match = re.match('(\d+)_(\d+)_(\w+).out$', entry)
        if match is not None:
            result.append( (match.group(1), match.group(2), match.group(3)) )
    result.sort()
    return result

def generate_table(path):
    data = []
    params = get_param_list(path)
    format_string = 'Processing file {{:>{}}} of {}...'.format(len(str(len(params))), len(params))
    for i, (window_size, kmer_size, tmax) in enumerate(params):
        print(format_string.format(i + 1), end='', flush=True)
        path_to_build_time = os.path.join(path, '{}_{}_{}_build.time'.format(window_size, kmer_size, tmax))
        path_to_query_time = os.path.join(path, '{}_{}_{}_query.time'.format(window_size, kmer_size, tmax))
        path_to_output = os.path.join(path, '{}_{}_{}.out'.format(window_size, kmer_size, tmax))
        path_to_internal_time = os.path.join(path, '{}_{}_{}.out.time'.format(window_size, kmer_size, tmax))

        # count_time = process_time(path_to_count_time)
        # layout_time =
        [build_time, build_ram] = process_time(path_to_build_time)
        [query_time, query_ram] = process_time(path_to_query_time)
        [query_ibf_time, query_reads_time, query_compute_time] = process_internal_time(path_to_internal_time)
        [tp, fp, fn] = [-1,-1,-1]#process_output(path_to_output)

        data.append([build_time,
                     build_ram,
                     query_time,
                     query_ibf_time,
                     query_reads_time,
                     query_compute_time,
                     query_ram,
                     fp,
                     fn])
        print('Done', flush=True)
    df = pd.DataFrame(data, columns = [('Construct', 'Time [MM:SS]'),
                                       ('Construct', 'RAM [MiB]'),
                                       ('Search', 'Overall [MM:SS.ss]'),
                                       ('Search', 'IBF I/O [SS.ss]'),
                                       ('Search', 'Reads I/O [SS.ss]'),
                                       ('Search', 'Compute [SS.ss]'),
                                       ('Search', 'RAM [MiB]'),
                                       ('Search', 'FP'),
                                       ('Search', 'FN')])
    df.index = [str(x).replace(',', ';').replace("'", '') for x in params]
    df.columns = pd.MultiIndex.from_tuples(df.columns, names=['','(w; k; size)'])
    return df

# input_path = os.path.join(INPUT_BASE, str(BINS))
# if not os.path.exists(input_path):
#     raise OSError("{} does not exist.".format(input_path))
# output_path = os.path.join(INPUT_BASE, str(BINS))
# os.makedirs(output_path, exist_ok=True)

# path_to_csv = os.path.join(output_path, 'table.csv')
# df = generate_table('/example/runs/raptor/65536/0.05')
df = generate_table('/example/runs/raptor/raptor_bench/65536/0.015')
print(df)
# df.to_csv(path_to_csv)



#!/usr/bin/env python3
# --------------------------------------------------------------------------------------------------
# Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
# Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
# This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
# shipped with this file and also available at: https://github.com/seqan/raptor/blob/main/LICENSE.md
# --------------------------------------------------------------------------------------------------
#
# Usage ram_usage.py <input_file> <output_file>
#
# Computes a table with RAM-Usage from a file containing output of `time -v`.
import argparse
import os
import pandas

parser = argparse.ArgumentParser(description='Parse time and memory consumption of compiling.', formatter_class=argparse.ArgumentDefaultsHelpFormatter)
parser.add_argument('input', type=str, help='File containing all outputs of `time -v`.')
parser.add_argument('output', type=str, help='File to write output to. (CSV)')
arguments = parser.parse_args()

file_names = []
ram_usages = []
run_times = []

with open(arguments.input, 'r') as input_file:
    parsing_ram_usage = False
    for line_number, line in enumerate(input_file):
        if line_number % 23 == 0:
            index_of_unit = line.rfind('-c')
            if index_of_unit != - 1:
                parsing_ram_usage = True
                file_names.append(line[index_of_unit:][:-2].split('/')[-1])
            else:
                parsing_ram_usage = False
        if parsing_ram_usage and ((line_number - 9) % 23) == 0:
            ram_usages.append(int(line.split(' ')[-1]) // 1024)
        if parsing_ram_usage and ((line_number - 4) % 23) == 0:
            run_times.append(line.strip().split(' ')[-1].lstrip('0:'))

with open(arguments.output, 'w') as output_file:
    df = pandas.DataFrame({'File' : file_names, 'RAM in MiB' : ram_usages, 'Time in s' : run_times})
    df = df.sort_values(by=['File'], ascending=True)
    df.to_csv(output_file, index=False)



#!/usr/bin/env python3

# --------------------------------------------------------------------------------------------------
# Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
# Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
# This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
# shipped with this file and also available at: https://github.com/seqan/raptor/blob/main/LICENSE.md
# --------------------------------------------------------------------------------------------------

import numpy as np
import pandas as pd

import os
import re
import time

from operator import itemgetter, attrgetter

# Adjust parameters in generate_table (bin and read count)
# stores results in `OUTPATH/table.csv`
# This directory contains all '.log' and '.time' files for a run
OUT_PATH = '<output directory with bin_number, e.g. /dev/shm/username/1024'
# Index is only build once, provide path to time log
path_to_build_fm_time = os.path.join(OUT_PATH, '19_32G_build_fm.time')

# Original DREAM-Yara does not use minimiser -> False
# New DREAM-Yara uses minimiser -> True
MINIMISERS=False

def process_time_log(path):
    time = []
    mem = []
    with open(path) as f:
        for i, line in enumerate(f):
            if i == 4:
                time = line.strip().split(' ')[-1].split(':')
                if len(time) == 3:
                    time = '{}:{}:{:02d}'.format(int(time[0]), int(time[1]), int(time[2]))
                elif len(time) == 2:
                    if int(time[0]) == 0:
                        time = '{}:{}'.format(time[0], time[1])
                    else:
                        time = '{}:{:02d}'.format(time[0], round(float(time[1])))
            if i == 9:
                mem = round(int(line.strip().split(' ')[-1]) / 1024)
    return [time, mem]

def process_mapper_log(path):
    with open(path) as f:
        for line in f:
            if line.startswith('Filter loading time'):
                components = line.split('\t')
                ibf_load_time = round(float(components[2].rstrip(' sec')), 1)
            if line.startswith('Reads filtering time'):
                components = line.split('\t')
                ibf_filter_time = round(float(components[2].rstrip(' sec')), 1)
            if line.startswith('Total reads'):
                components = line.split('\t')
                total_reads = int(float(components[3].strip()))
            if line.startswith('Mapped reads'):
                components = line.split('\t')
                mapped_reads = int(float(components[3].strip()))
            if line.startswith('Avg reads per bin'):
                components = line.split('\t')
                avg_per_bin = int(float(components[2].strip()))
    return [ibf_load_time, ibf_filter_time, total_reads - mapped_reads, avg_per_bin]

def get_param_list(path = OUT_PATH):
    result = []
    for entry in os.listdir(path):
        if MINIMISERS:
            match = re.match('(\d+)_(\d+)_(\d+)G_mapper_(\d+).time$', entry)
        else:
            match = re.match('(\d+)_(\d+)G_mapper_(\d+).time$', entry)
        if match is not None:
            if MINIMISERS:
                result.append( (int(match.group(1)), int(match.group(2)), int(match.group(3)), int(match.group(4))) )
            else:
                result.append( (int(match.group(1)), int(match.group(2)), int(match.group(3))) )
    return result

# (how many bins: int), (how many reads: int)
def generate_table(bin_count=1024, read_count=1048576):
    data = []
    if MINIMISERS:
        params = sorted(get_param_list(), key=itemgetter(0,3,2))
    else:
        params = sorted(get_param_list(), key=itemgetter(0,2,1))
    format_string = 'Processing file {{:>{}}} of {}...'.format(len(str(len(params))), len(params))

    [indexer_time, indexer_ram] = process_time_log(path_to_build_fm_time)

    for i, tuple in enumerate(params):
        print(format_string.format(i + 1), end='', flush=True)
        # path_to_build_ibf_log = os.path.join(OUT_PATH, '{}_{}_{}G_build_ibf.log'.format(window_size, kmer_size, ibf_size))
        if MINIMISERS:
            window_size, kmer_size, ibf_size, read_size = tuple
            path_to_build_ibf_time = os.path.join(OUT_PATH, '{}_{}_{}G_build_ibf.time'.format(window_size, kmer_size, ibf_size))
            path_to_mapper_time = os.path.join(OUT_PATH, '{}_{}_{}G_mapper_{}.time'.format(window_size, kmer_size, ibf_size, read_size))
            path_to_mapper_log = os.path.join(OUT_PATH, '{}_{}_{}G_mapper_{}.log'.format(window_size, kmer_size, ibf_size, read_size))
        else:
            kmer_size, ibf_size, read_size = tuple
            path_to_build_ibf_time = os.path.join(OUT_PATH, '{}_{}G_build_ibf.time'.format(kmer_size, ibf_size))
            path_to_mapper_time = os.path.join(OUT_PATH, '{}_{}G_mapper_{}.time'.format(kmer_size, ibf_size, read_size))
            path_to_mapper_log = os.path.join(OUT_PATH, '{}_{}G_mapper_{}.log'.format(kmer_size, ibf_size, read_size))

        [build_ibf_time, build_ibf_ram] = process_time_log(path_to_build_ibf_time)
        [mapper_time, mapper_ram] = process_time_log(path_to_mapper_time)

        [mapper_ibf_load_time, mapper_ibf_filter_time, mapper_unmapped_reads, mapper_avg_per_bin] = process_mapper_log(path_to_mapper_log)

        data.append([build_ibf_time, build_ibf_ram,
                     indexer_time, indexer_ram,
                     mapper_time, mapper_ibf_load_time, mapper_ibf_filter_time, mapper_ram, mapper_unmapped_reads, mapper_avg_per_bin])
        print('Done', flush=True)
    df = pd.DataFrame(data, columns = [('IBF', 'Time'),  ('IBF', 'RAM'),
                                       ('Indexer','Time'),  ('Indexer','RAM'),
                                       ('Mapper','Time'),  ('Mapper','IBF Load Time'), ('Mapper','IBF Filter Time'),  ('Mapper','RAM'), ('Mapper','Unmapped Reads'), ('Mapper', 'Processed Reads per Bin')])
    df.index = [str(x).replace(',', ';').replace("'", '').replace('m', '') for x in params]
    if MINIMISERS:
        df.columns = pd.MultiIndex.from_tuples(df.columns, names=['','w; k; IBF size; read length'])
    else:
        df.columns = pd.MultiIndex.from_tuples(df.columns, names=['','k; IBF size; read length'])
    return df

path_to_csv = os.path.join(OUT_PATH, 'table.csv')
df = generate_table()
df.to_csv(path_to_csv)



#!/usr/bin/env python3

# --------------------------------------------------------------------------------------------------
# Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
# Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
# This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
# shipped with this file and also available at: https://github.com/seqan/raptor/blob/main/LICENSE.md
# --------------------------------------------------------------------------------------------------

import numpy as np
import pandas as pd

import os
import re

PATTERN_SIZE=250
FREQUENCIES_DIR = '<path>/{}_p2'.format(PATTERN_SIZE)

def get_wk_list(path = FREQUENCIES_DIR):
    result = []
    for entry in os.listdir(path):
        match = re.match('(\d+)_(\d+)_(\d+\w).out.minimiser_counts$', entry)
        if match is not None:
            result.append( (match.group(1), match.group(2), match.group(3)) )
    return result

def generate_table():
    data = []
    params = get_wk_list()
    for (window_size, kmer_size, ibf_size) in params:
        column_name = 'w{} k{}'.format(window_size, kmer_size)
        path_to_threshold = os.path.join(FREQUENCIES_DIR, '{}_{}_{}.out.minimiser_counts'.format(window_size, kmer_size, ibf_size))
        data.append(pd.read_csv(path_to_threshold, delimiter='\t', header=0, index_col=False, usecols=[1], names=[column_name]))
    output_file = os.path.join(FREQUENCIES_DIR, 'p{}_w{}_k{}.frequencies'.format(PATTERN_SIZE, window_size, kmer_size))
    pd.concat(data, axis=1, copy=False).to_csv(output_file, float_format='%d')

generate_table()



#!/usr/bin/env python3

# --------------------------------------------------------------------------------------------------
# Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
# Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
# This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
# shipped with this file and also available at: https://github.com/seqan/raptor/blob/main/LICENSE.md
# --------------------------------------------------------------------------------------------------

import numpy as np
import pandas as pd
from math import ceil

import os
import re

COUNTS_DIR = '<output_of_counting>' # directory containing w_k.counts, e.g. 23_19.counts

def get_wk_list(path = COUNTS_DIR):
    result = []
    for entry in os.listdir(path):
        match = re.match('(\d+)_(\d+).counts$', entry)
        if match is not None:
            result.append( (match.group(1), match.group(2)) )
    return sorted(result)

def process_file(path):
    with open(path, 'r') as file:
        total_text_size = int(file.readline().strip())
        bin_sizes = []
        for line in file:
            bin_sizes.append(int(line.strip()))
    return (total_text_size, max(bin_sizes), ceil(sum(bin_sizes)/len(bin_sizes)), sum(bin_sizes))

def generate_table():
    data = []
    params = get_wk_list()
    for (window_size, kmer_size) in params:
        (total_text, max, avg, sum) = process_file(os.path.join(COUNTS_DIR, '{}_{}.counts'.format(window_size, kmer_size)))
        data.append([total_text, max, avg, sum])
    df = pd.DataFrame(data, columns = ['text size', 'max bin', 'avg bin', 'sum bin'])
    df.index = ['w{} k{}'.format(window_size, kmer_size) for [window_size, kmer_size] in params]
    output_file = os.path.join(COUNTS_DIR, 'counts.csv')
    df.to_csv(output_file)

generate_table()



#!/usr/bin/env python3

# --------------------------------------------------------------------------------------------------
# Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
# Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
# This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
# shipped with this file and also available at: https://github.com/seqan/raptor/blob/main/LICENSE.md
# --------------------------------------------------------------------------------------------------

import numpy as np
import pandas as pd

import os
import re
import time

BINS=1024
READ_COUNT=1048576
INPUT_BASE = '/home/infri/develop/raptor/build/util/test/results' # E.g., /dev/shm/username; should contain BINS subdirectory.
OUTPUT_BASE = '/home/infri/develop/raptor/build/util/test/results' # Will create BINS subdirectory.
EVAL_ENERGY=False # Energy consumption was measured in the benchmark.

input_path = os.path.join(INPUT_BASE, str(BINS))
if not os.path.exists(input_path):
    raise OSError("{} does not exist.".format(input_path))
output_path = os.path.join(INPUT_BASE, str(BINS))
os.makedirs(output_path, exist_ok=True)

def process_output(path):
    with open(path) as f:
        tp = 0
        fp = 0
        fn = 0
        for line in f:
            if line[0] == '#':
                continue
            try:
                [x, y] = line.strip().split('\t')
            except ValueError:
                fn += 1
                continue
            [read_id, bins] = [int(x), [int(e) for e in y.split(',') if e != '']]
            true_id = (read_id % READ_COUNT) // (READ_COUNT // BINS)
            if true_id in bins:
                tp += 1
                if len(bins) != 1:
                    fp += len(bins) - 1
            else:
                fn += 1
                fp += len(bins)
        return [tp,fp,fn]

def process_time_log(path):
    time = []
    mem = []
    with open(path) as f:
        for i, line in enumerate(f):
            if i == 4:
                time = line.strip().split(' ')[-1].split(':')
                if len(time) == 3:
                    time = '{}:{:02d}'.format(int(time[0]) * 60 + int(time[1]), int(time[2]))
                elif len(time) == 2:
                    if int(time[0]) == 0:
                        time = '{}:{}'.format(time[0], time[1])
                    else:
                        time = '{}:{:02d}'.format(time[0], round(float(time[1])))
            if i == 9:
                mem = round(int(line.strip().split(' ')[-1]) / 1024)
    return [time, mem]

def process_internal_time(path):
    with open(path) as f:
        line = f.readline()
        line = f.readline()
        [ibf_time, read_time, compute_time] = line.strip().split('\t')
        return [ibf_time, read_time, compute_time]

def process_energy(path):
    if not EVAL_ENERGY:
        return [-1, -1]
    with open(path) as f:
        line = f.readline()
        line = f.readline()
        line = f.readline()
        line = f.readline()
        line = f.readline()
        line = f.readline()
        energy_pkg = line.strip().split(' ')[0]
        line = f.readline()
        energy_ram = line.strip().split(' ')[0]
        return [energy_pkg, energy_ram]

def get_param_list(path = output_path):
    result = []
    for entry in os.listdir(path):
        match = re.match('(\d+)_(\d+)_(\d+\w).out$', entry)
        if match is not None:
            result.append( (match.group(1), match.group(2), match.group(3)) )
    result.sort(key=lambda entry: int(entry[2][:-1]))
    return result

def generate_table_unpartitioned():
    data = []
    params = get_param_list()
    format_string = 'Processing file {{:>{}}} of {}...'.format(len(str(len(params))), len(params))
    for i, (window_size, kmer_size, ibf_size) in enumerate(params):
        print(format_string.format(i + 1), end='', flush=True)
        path_to_build_log = os.path.join(output_path, '{}_{}_{}_build.log'.format(window_size, kmer_size, ibf_size))
        path_to_build_perf = os.path.join(input_path, '{}_{}_{}_build.perf'.format(window_size, kmer_size, ibf_size))
        path_to_query_log = os.path.join(output_path, '{}_{}_{}_query.log'.format(window_size, kmer_size, ibf_size))
        path_to_query_perf = os.path.join(input_path, '{}_{}_{}_query.perf'.format(window_size, kmer_size, ibf_size))
        path_to_output = os.path.join(output_path, '{}_{}_{}.out'.format(window_size, kmer_size, ibf_size))
        path_to_internal_time = os.path.join(output_path, '{}_{}_{}.out.time'.format(window_size, kmer_size, ibf_size))

        [build_time, build_ram] = process_time_log(path_to_build_log)
        [build_energy_pkg, build_energy_ram] = process_energy(path_to_build_perf)
        [query_time, query_ram] = process_time_log(path_to_query_log)
        [query_energy_pkg, query_energy_ram] = process_energy(path_to_query_perf)
        [query_ibf_time, query_reads_time, query_compute_time] = process_internal_time(path_to_internal_time)
        [tp, fp, fn] = process_output(path_to_output)

        data.append([build_time,
                     build_ram,
                     build_energy_pkg,
                     build_energy_ram,
                     query_time,
                     query_ibf_time,
                     query_reads_time,
                     query_compute_time,
                     query_ram,
                     query_energy_pkg,
                     query_energy_ram,
                     fp,
                     fn])
        print('Done', flush=True)
    df = pd.DataFrame(data, columns = [('Construct', 'Time [MM:SS]'),
                                       ('Construct', 'RAM [MiB]'),
                                       ('Construct', 'energy-pkg [J]'),
                                       ('Construct', 'energy-ram [J]'),
                                       ('Search', 'Overall [MM:SS.ss]'),
                                       ('Search', 'IBF I/O [SS.ss]'),
                                       ('Search', 'Reads I/O [SS.ss]'),
                                       ('Search', 'Compute [SS.ss]'),
                                       ('Search', 'RAM [MiB]'),
                                       ('Search', 'energy-pkg [J]'),
                                       ('Search', 'energy-ram [J]'),
                                       ('Search', 'FP'),
                                       ('Search', 'FN')])
    df.index = [str(x).replace(',', ';').replace("'", '') for x in params]
    df.columns = pd.MultiIndex.from_tuples(df.columns, names=['','(w; k; size)'])
    if not EVAL_ENERGY:
        df = df.drop([('Construct', 'energy-pkg [J]'), ('Construct', 'energy-ram [J]'),
                      ('Search', 'energy-pkg [J]'), ('Search', 'energy-ram [J]')], axis=1)
    return df

path_to_csv = os.path.join(output_path, 'table.csv')
df = generate_table_unpartitioned()
df.to_csv(path_to_csv)
